# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import datetime
import sys
import types
import typing
import uuid as _uuid
from builtins import property as _property

import winrt._winrt
import winrt.system
import winrt.windows.devices.geolocation
import winrt.windows.foundation
import winrt.windows.foundation.collections
import winrt.windows.globalization
import winrt.windows.services.maps

from winrt.windows.services.maps.localsearch import LocalLocationFinderStatus

Self = typing.TypeVar('Self')

@typing.final
class LocalCategories_Static(type):
    @_property
    def all(cls) -> str: ...
    @_property
    def bank_and_credit_unions(cls) -> str: ...
    @_property
    def eat_drink(cls) -> str: ...
    @_property
    def hospitals(cls) -> str: ...
    @_property
    def hotels_and_motels(cls) -> str: ...
    @_property
    def parking(cls) -> str: ...
    @_property
    def see_do(cls) -> str: ...
    @_property
    def shop(cls) -> str: ...

@typing.final
class LocalCategories(winrt.system.Object, metaclass=LocalCategories_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LocalCategories: ...

@typing.final
class LocalLocation(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LocalLocation: ...
    @_property
    def address(self) -> typing.Optional[winrt.windows.services.maps.MapAddress]: ...
    @_property
    def data_attribution(self) -> str: ...
    @_property
    def description(self) -> str: ...
    @_property
    def display_name(self) -> str: ...
    @_property
    def identifier(self) -> str: ...
    @_property
    def phone_number(self) -> str: ...
    @_property
    def point(self) -> typing.Optional[winrt.windows.devices.geolocation.Geopoint]: ...
    @_property
    def category(self) -> str: ...
    @_property
    def hours_of_operation(self) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[LocalLocationHoursOfOperationItem]]: ...
    @_property
    def rating_info(self) -> typing.Optional[LocalLocationRatingInfo]: ...

@typing.final
class LocalLocationFinder_Static(type):
    def find_local_locations_async(cls, search_term: str, search_area: typing.Optional[winrt.windows.devices.geolocation.Geocircle], local_category: str, max_results: winrt.system.UInt32, /) -> winrt.windows.foundation.IAsyncOperation[LocalLocationFinderResult]: ...

@typing.final
class LocalLocationFinder(winrt.system.Object, metaclass=LocalLocationFinder_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LocalLocationFinder: ...

@typing.final
class LocalLocationFinderResult(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LocalLocationFinderResult: ...
    @_property
    def local_locations(self) -> typing.Optional[winrt.windows.foundation.collections.IVectorView[LocalLocation]]: ...
    @_property
    def status(self) -> LocalLocationFinderStatus: ...

@typing.final
class LocalLocationHoursOfOperationItem(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LocalLocationHoursOfOperationItem: ...
    @_property
    def day(self) -> winrt.windows.globalization.DayOfWeek: ...
    @_property
    def span(self) -> datetime.timedelta: ...
    @_property
    def start(self) -> datetime.timedelta: ...

@typing.final
class LocalLocationRatingInfo(winrt.system.Object):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> LocalLocationRatingInfo: ...
    @_property
    def aggregate_rating(self) -> typing.Optional[typing.Optional[winrt.system.Double]]: ...
    @_property
    def provider_identifier(self) -> str: ...
    @_property
    def rating_count(self) -> typing.Optional[typing.Optional[winrt.system.Int32]]: ...

@typing.final
class PlaceInfoHelper_Static(type):
    def create_from_local_location(cls, location: typing.Optional[LocalLocation], /) -> typing.Optional[winrt.windows.services.maps.PlaceInfo]: ...

@typing.final
class PlaceInfoHelper(winrt.system.Object, metaclass=PlaceInfoHelper_Static):
    @staticmethod
    def _from(obj: winrt.system.Object, /) -> PlaceInfoHelper: ...




# WARNING: Please don't edit this file. It was generated by Python/WinRT v2.0.0-beta.2

import enum

import winrt.system
from winrt import _winrt_windows_services_maps_localsearch

__all__ = [
    "LocalLocationFinderStatus",
    "LocalCategories",
    "LocalLocation",
    "LocalLocationFinder",
    "LocalLocationFinderResult",
    "LocalLocationHoursOfOperationItem",
    "LocalLocationRatingInfo",
    "PlaceInfoHelper",
]

class LocalLocationFinderStatus(enum.IntEnum):
    SUCCESS = 0
    UNKNOWN_ERROR = 1
    INVALID_CREDENTIALS = 2
    INVALID_CATEGORY = 3
    INVALID_SEARCH_TERM = 4
    INVALID_SEARCH_AREA = 5
    NETWORK_FAILURE = 6
    NOT_SUPPORTED = 7

LocalCategories = _winrt_windows_services_maps_localsearch.LocalCategories
LocalLocation = _winrt_windows_services_maps_localsearch.LocalLocation
LocalLocationFinder = _winrt_windows_services_maps_localsearch.LocalLocationFinder
LocalLocationFinderResult = _winrt_windows_services_maps_localsearch.LocalLocationFinderResult
LocalLocationHoursOfOperationItem = _winrt_windows_services_maps_localsearch.LocalLocationHoursOfOperationItem
LocalLocationRatingInfo = _winrt_windows_services_maps_localsearch.LocalLocationRatingInfo
PlaceInfoHelper = _winrt_windows_services_maps_localsearch.PlaceInfoHelper
